# Condition


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**expression** | **str** | A Google CEL expression, expressed as a string. | 
**parameters** | [**dict[str, ConditionParamTypeRef]**](ConditionParamTypeRef.md) | A map of parameter names to the parameter&#39;s defined type reference. | [optional] 
**metadata** | [**ConditionMetadata**](ConditionMetadata.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


